@@ -11,9 +11,9 @@ except (ModuleNotFoundError, ValueError):
     from .separate.aggregation import aggregate
     
     
-    
+__version__ = '0.9.5'
 from .load_datasets import load_images
-from .symbolic_representation import (image_compress, image_decompress, ABBAbase,
+from .symbolic_representation import (image_compress, image_decompress, ABBAbase, ABBA,
                                       get_patches, patched_reconstruction, fabba_model,
                                       symbolsAssign, fillna)
 from .symbolic_representation import _compress as compress
